/*
 * Created on May 16, 2005
 *
 */
package com.sunlabs.archsim.build;

import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

import com.sunlabs.archsim.classRegistry.ClassRegistry;
import com.sunlabs.archsim.engine.Director;

/**
 *
 * Copyright  2005 Sun Microsystems Inc. All rights reserved. Use is subject to license terms.
 * 
 * @author ib27688
 *
 * An aggregate for the list of connection and the 
 */
public class ModelDescription {
	
	protected Director director= Director.getInstance();
	
	/** class registry for component classes */
	public ClassRegistry registry;
	
	/** the list of connections */
	public List<ConnectionRecord> connectionRecordList;

	/** model name */
	String name;
	
	/* A mapping from component names to components.
	 * Each name can appear only once - this is ensured by the code
	 * that reads XML input.
	 */
	public HashMap<String, ComponentRecord> componentNameMap;
	
	public ModelDescription() {
		name= null; 
		
		registry= ClassRegistry.instance;
		
		connectionRecordList = new LinkedList<ConnectionRecord>();

		componentNameMap= new HashMap<String, ComponentRecord>();
		
	} // ModelDescription constructor

	public void load(String fileName) {
		ModelLoader ldr= new ModelLoader(this);
		ldr.loadFile(fileName);
	} // load

	/**
	 * List the components and connectins in the model.
	 * Used in testing.
	 */
	public void print() {
		director.info("MODEL NAME: " + name);

		// go through components
		Iterator ci= componentNameMap.values().iterator();
		while (ci.hasNext()) {
			ComponentRecord cr= (ComponentRecord) ci.next();
			director.info("COMPONENT NAME: " + cr.name 
					+ " COMPONENT TYPE: " + cr.type.getName());
		}
		
		// go through connections
		ci= connectionRecordList.iterator();
		while (ci.hasNext()) {
			ConnectionRecord cr= (ConnectionRecord) ci.next();
			director.info("CONNECTION " + cr.name);
			
			// sources first
			Iterator si= cr.sources.iterator();
			while(si.hasNext()) {
				ConnectionPoint src= (ConnectionPoint)si.next();
				director.info("\t FROM COMPONENT " 
						+ src.componentName 
						+ ", AT TERMINAL "
						+ src.terminalName);
			}
			
			// now destinations
			Iterator di= cr.destinations.iterator();
			while (di.hasNext()) {
				ConnectionPoint dest= (ConnectionPoint)di.next();
				director.info("\t TO COMPONENT " 
						+ dest.componentName 
						+ ", AT TERMINAL "
						+ dest.terminalName);				
			}
		} // while ci has next
		
	} // print
	
} // class ModelDescription
