/*
 * Copyright  2005 Sun Microsystems Inc. All rights reserved. Use is subject to license terms.
 *  
 */

/*
 * Created on Feb 11, 2005
 *
 */
package com.sunlabs.archsim.tests.arbiter;

import java.util.Iterator;

import com.sunlabs.archsim.base.simulation.Delay;
import com.sunlabs.archsim.gasp.Action;
import com.sunlabs.archsim.gasp.Function;
import com.sunlabs.archsim.gasp.Terminal;
import com.sunlabs.archsim.gasp.terminals.NumberedInput;

/**
 * @author ib27688
 *
 * FIFO action - used for testing.
 */
public class ArbiterTestFifoAction extends Action {
	
	public ArbiterTestFifoAction(String name) {
		super(name);
		outputFunctions.put("dataOut", new PassData());
		outputFunctions.put("ackDataIn", new ActionFired());
	} // FifoAction
	
	
	/** Simply pass the data from input terminal 0 */
	private class PassData extends Function {
		
		public PassData() {
			super("PassData");
			functionDelay= new Delay(10); // was 10
		}
		
		public Object value() {
			Iterator ti= terminals.iterator();
			boolean found= false;
			Terminal t= null;
			while (!found && ti.hasNext()) {
				t= (Terminal)(ti.next());
				if (t instanceof NumberedInput
						&& ((NumberedInput)t).number() == 0) {
					found= true;
				}
			}
			if (found) {
				return t.getData();
			}
			else {
				return null;
			}
		} // value
	} // PassData

	/** Vacuous function used to acknowldge that the action has fired */ 
	private class ActionFired extends Function {
		
		public ActionFired() {
			super("Vacous");
			functionDelay= new Delay(0); // was 10
		}
	
		public Object value() {
			return null;
		} // value
	} // AcknowledgeData
	
} // ArbiterTestFifoAction
